# foran

Answering if a local is in front of its remote.

The English "in front" may translate to the Danish "foran".

... and the default report stem `foran-eller-bagved` alludes to the English "In front or behind?" question which corresponds to the Danish "Foran eller bagved?"

## Status

Experimental.

**Note**: The default branch is `default`.
